#!/usr/bin/env seed
// Returns: 0
// STDIN:2+2
// STDOUT:4.000000
// STDERR:

Seed.import_namespace("readline");
Seed.print(eval(readline.readline("")));
